import os
from flask import Flask, render_template, request, send_from_directory, current_app
from flask_login import login_required
from . import my_files
from .. import db
from ..models import File
from ..file_indexer import FileIndexer as indexer

@my_files.route('/my_files',  methods=['GET', 'POST'])
@login_required
def myfiles():

    parent_dir = request.args.get("parent_dir")
    crumbs = [{"name": "/", "full_path": "/"}]
    if parent_dir:
        if parent_dir != "/":
            parent_dir = parent_dir.replace('_', ' ') + "/"

        more_crumbs = parent_dir.split("/")
        more_crumbs.pop()
        more_crumbs.reverse()
        more_crumbs.pop()
        more_crumbs.reverse()
        main_sequence = []
        for word in more_crumbs:
            main_sequence.append(word)
            sub_sequence = []
            sub_sequence.extend(main_sequence)
            sub_sequence = '/'.join(sub_sequence)
            crumbs.append({"name": word, "full_path": '/' + sub_sequence})

    folders = db.session.query(File).filter(File.parent_dir == parent_dir,
                                            File.is_dir == True).order_by(File.filename).all()
    files = db.session.query(File).filter(File.parent_dir == parent_dir,
                                          File.is_dir == False).order_by(File.filename).order_by(File.filename).all()

    return render_template("my_files.html", folders=folders,
                           files=files, parent_dir=parent_dir,
                           style_sheet="my_files.css", crumbs=crumbs)


@my_files.route('/my_files/download/<id>', methods=['GET', 'POST'])
@login_required
def file_download(id):
    app = Flask(__name__)
    app.config["UPLOAD_FOLDER"] = os.path.join(current_app.root_path, "uploads/")
    file = File.query.filter_by(id=id).first()
    file_dir = app.config['UPLOAD_FOLDER']
    index = indexer(file_dir)
    on_smb = index.conn.getAttributes(index.share_name, path=file.full_path)
    if on_smb.filename == file.filename:
        index.download_file(full_path=file.full_path, file_name=file.filename)
        return send_from_directory(directory=file_dir, filename=file.filename)


@my_files.route('/my_files/cleanup/<id>', methods=['POST'])
@login_required
def file_cleanup(id):
    # get file name
    file = File.query.filter_by(id=id).first()
    filename = file.filename
    filepath = os.path.join(current_app.root_path, "uploads/", filename)
    print("Deleting {}".format(filepath))

    # verify file exists on local filesystem, delete
    if os.path.exists(filepath):
        try:
            os.remove(filepath)
            if not os.path.exists(filepath):
                message = {"DeleteStatus": "Success"}
        except[OSError]:
            message = {"DeleteStatus": "CouldNotDelete"}
    else:
        message = {"DeleteStatus": "NotFound"}

    print(message)

    return message

